@@ -1,7 +1,7 @@
 // Install script for Enigmail
 
 var err;
-const APP_VERSION="0.95.5.0";
+const APP_VERSION="0.95.7.0";
 
 
 const ABI_PLATFORM_LINUX="Linux_x86-gcc3";
@@ -51,7 +51,7 @@ function getPlatform() {
       platformNode = APP_PLATFORM_MAC;
     else if (!platformStr.search(/^Win/))
       platformNode = APP_PLATFORM_WIN;
-    else if (!platformStr.search(/Linux/))
+    else if (platformStr.search(/Linux/) >= 0)
       platformNode = APP_PLATFORM_LINUX;
     else if (!platformStr.search(/^OS\/2/))
       platformNode = APP_PLATFORM_OS2;
@@ -106,6 +106,8 @@ if (!verifyDiskSpace(fProgram, srDest)) {
   case APP_PLATFORM_OS2:
     addDirectory("", "platform/"+ABI_PLATFORM_OS2+"/components",    fComponents, "");
     break;
+  default:
+    addDirectory("", "platform/OpenBSD_x86-gcc3/components",    fComponents, "");
   }
 
   err = getLastError();
